@@ -30,6 +30,12 @@ residuals( estResult )
 
 print.default( estResult )
 
+fitted( estResult )
+all.equal( fitted( estResult ), predict( estResult ) )
+all.equal( log( fitted( estResult ) ), predict( estResult, dataLogged = TRUE ) )
+all.equal( fitted( estResult ), predict( estResult, newdata = germanFarms ) )
+
+
 # estimate the translog production function with a different order of inputs
 estResultOrder <- translogEst( yName = "qOutput",
    xNames = c( "qLabor", "qVarInput", "land", "time" ),
@@ -61,6 +67,13 @@ estResultLog <- translogEst( "qLogOutput",
    data = germanFarms, dataLogged = TRUE )
 all.equal( estResult[ -c(1,6,12,13,16) ], estResultLog[ -c(1,6,12,13,16) ] )
 all.equal( estResult$fitted, exp( estResultLog$fitted ) )
+fitted( estResultLog )
+all.equal( fitted( estResultLog ), predict( estResultLog ) )
+all.equal( exp( fitted( estResultLog ) ),
+   predict( estResultLog, dataLogged = FALSE ) )
+all.equal( fitted( estResultLog ),
+   predict( estResultLog, newdata = germanFarms ) )
+
 
 ## testing translogCalc
 fitted <- translogCalc( c( "qLabor", "land", "qVarInput", "time" ),
@@ -197,28 +210,28 @@ germanFarms$pLand <- 200 + 15 * germanFarms$time
 germanFarms$pTime <- 1
 
 # compute the marginal costs of producing the output
-margCost <- translogProdFuncMargCost( yNames = "qOutput",
+margCost <- translogProdFuncMargCost( yName = "qOutput",
    xNames = c( "qLabor", "land", "qVarInput", "time" ),
    wNames = c( "pLabor", "pLand", "pVarInput", "pTime" ),
    data = germanFarms, coef = coef( estResult ) )
 print( margCost )
 
 # compute the marginal costs again with different order of inputs
-margCostOrder <- translogProdFuncMargCost( yNames = "qOutput",
+margCostOrder <- translogProdFuncMargCost( yName = "qOutput",
    xNames = c( "qLabor", "qVarInput", "land", "time" ),
    wNames = c( "pLabor", "pVarInput", "pLand", "pTime" ),
    data = germanFarms, coef = coef( estResultOrder ) )
 all.equal( margCost, margCostOrder )
 
 # compute the marginal costs again with different order of inputs
-margCostOrder2 <- translogProdFuncMargCost( yNames = "qOutput",
+margCostOrder2 <- translogProdFuncMargCost( yName = "qOutput",
    xNames = c( "land", "qVarInput", "qLabor", "time" ),
    wNames = c( "pLand", "pVarInput", "pLabor", "pTime" ),
    data = germanFarms, coef = coef( estResultOrder2 ) )
 all.equal( margCost, margCostOrder2 )
 
 # compute the marginal costs again with different order of inputs
-margCostOrder3 <- translogProdFuncMargCost( yNames = "qOutput",
+margCostOrder3 <- translogProdFuncMargCost( yName = "qOutput",
    xNames = c( "land", "qVarInput", "time", "qLabor" ),
    wNames = c( "pLand", "pVarInput", "pTime", "pLabor" ),
    data = germanFarms, coef = coef( estResultOrder3 ) )
@@ -398,7 +411,8 @@ print.default( estResult2 )
 
 ## panel data
 data( "GrunfeldGreene", package = "systemfit" )
-ggData <- plm.data( GrunfeldGreene, c( "firm", "year" ) )
+ggData <- pdata.frame( GrunfeldGreene, c( "firm", "year" ),
+   row.names = FALSE )
 ggData$logInvest <- log( ggData$invest )
 ggData$logValue <- log( ggData$value )
 ggData$logCapital <- log( ggData$capital )
@@ -450,7 +464,7 @@ ggElaRanLogMet <- elas( ggResultRanLog )
 all.equal( ggElaRanMet, ggElaRanLogMet, check.attributes = FALSE )
 
 ## panel data with a shifter
-ggData$yearInt <- as.integer( as.character( ggData$year ) )
+ggData$yearInt <- as.numeric( as.character( ggData$year ) )
 ggData$tech <- exp( ggData$yearInt - min( ggData$yearInt ) )
 # fixed effects
 ggResShifter <- translogEst( "invest", c( "value", "capital" ), ggData,
